# eric7.DebugClients.Python.DebugVariables

Module implementing classes and functions to dump variable contents.

### Global Attributes

_MapCount
_TryArray
_TypeMap
arrayResolver
defaultResolver
dictResolver
dictViewResolver
listResolver
multiValueDictResolver
ndarrayResolver
qtResolver
setResolver

### Classes

ArrayResolver | Class used to resolve from array.array including some meta data.
BaseResolver | Base class of the resolver class tree.
DefaultResolver | Class used to resolve the default way.
DictResolver | Class used to resolve from a dictionary.
DictViewResolver | Class used to resolve from dict views.
ListResolver | Class used to resolve from a tuple or list.
MultiValueDictResolver | Class used to resolve from Django multi value dictionaries.
NdArrayResolver | Class used to resolve from numpy ndarray including some meta data.
QtResolver | Class used to resolve the Qt implementations.
SetResolver | Class used to resolve from a set or frozenset.

### Functions

_initTypeMap | Protected function to initialize the type map.
getResolver | Public method to get the resolver based on the type info of an object.
updateTypeMap | Public function to update the type map based on module imports.

## ArrayResolver

Class used to resolve from array.array including some meta data.

### Derived from

BaseResolver

### Class Attributes

TypeCodeMap

### Class Methods

None

### Methods

getVariableList | Public method to get the attributes of a variable as a list.
resolve | Public method to get an attribute from a variable.

### Static Methods

None

#### ArrayResolver.getVariableList

getVariableList(var)

Public method to get the attributes of a variable as a list.

var (Any)
  variable to be converted

Yield:
  tuple containing the batch start index and a list containing the variable attributes

Yield Type:
  tuple of (int, list)

#### ArrayResolver.resolve

resolve(var, attribute)

Public method to get an attribute from a variable.

var (array.array)
  variable to extract an attribute or value from
attribute (str)
  id of the value to extract

Return:
  value of the attribute

Return Type:
  Any

Up

## BaseResolver

Base class of the resolver class tree.

### Derived from

None

### Class Attributes

None

### Class Methods

None

### Methods

getVariableList | Public method to get the attributes of a variable as a list.
resolve | Public method to get an attribute from a variable.

### Static Methods

None

#### BaseResolver.getVariableList

getVariableList(var)

Public method to get the attributes of a variable as a list.

var (Any)
  variable to be converted

Return:
  list containing the variable attributes

Return Type:
  list

#### BaseResolver.resolve

resolve(var, attribute)

Public method to get an attribute from a variable.

var (Any)
  variable to extract an attribute or value from
attribute (str)
  name of the attribute to extract

Return:
  value of the attribute

Return Type:
  Any

Up

## DefaultResolver

Class used to resolve the default way.

### Derived from

BaseResolver

### Class Attributes

None

### Class Methods

None

### Methods

getVariableList | Public method to get the attributes of a variable as a list.

### Static Methods

None

#### DefaultResolver.getVariableList

getVariableList(var)

Public method to get the attributes of a variable as a list.

var (Any)
  variable to be converted

Yield:
  tuple containing the batch start index and a list containing the variable attributes

Yield Type:
  tuple of (int, list)

Up

## DictResolver

Class used to resolve from a dictionary.

### Derived from

BaseResolver

### Class Attributes

None

### Class Methods

None

### Methods

getVariableList | Public method to get the attributes of a variable as a list.
keyToStr | Public method to get a string representation for a key.
resolve | Public method to get an attribute from a variable.

### Static Methods

None

#### DictResolver.getVariableList

getVariableList(var)

Public method to get the attributes of a variable as a list.

var (Any)
  variable to be converted

Yield:
  tuple containing the batch start index and a list containing the variable attributes

Yield Type:
  tuple of (int, list)

#### DictResolver.keyToStr

keyToStr(key)

Public method to get a string representation for a key.

key (Any)
  key to be converted

Return:
  string representation of the given key

Return Type:
  str

#### DictResolver.resolve

resolve(var, attribute)

Public method to get an attribute from a variable.

var (dict)
  variable to extract an attribute or value from
attribute (str)
  name of the attribute to extract

Return:
  value of the attribute

Return Type:
  Any

Up

## DictViewResolver

Class used to resolve from dict views.

### Derived from

ListResolver

### Class Attributes

None

### Class Methods

None

### Methods

getVariableList | Public method to get the attributes of a variable as a list.
resolve | Public method to get an attribute from a variable.

### Static Methods

None

#### DictViewResolver.getVariableList

getVariableList(var)

Public method to get the attributes of a variable as a list.

var (Any)
  variable to be converted

Yield:
  tuple containing the batch start index and a list containing the variable attributes

Yield Type:
  tuple of (int, list)

#### DictViewResolver.resolve

resolve(var, attribute)

Public method to get an attribute from a variable.

var (dict_items, dict_keys or dict_values)
  variable to extract an attribute or value from
attribute (str)
  id of the value to extract

Return:
  value of the attribute

Return Type:
  Any

Up

## ListResolver

Class used to resolve from a tuple or list.

### Derived from

BaseResolver

### Class Attributes

None

### Class Methods

None

### Methods

getVariableList | Public method to get the attributes of a variable as a list.
resolve | Public method to get an attribute from a variable.

### Static Methods

None

#### ListResolver.getVariableList

getVariableList(var)

Public method to get the attributes of a variable as a list.

var (Any)
  variable to be converted

Yield:
  tuple containing the batch start index and a list containing the variable attributes

Yield Type:
  tuple of (int, list)

#### ListResolver.resolve

resolve(var, attribute)

Public method to get an attribute from a variable.

var (tuple or list)
  variable to extract an attribute or value from
attribute (str)
  name of the attribute to extract

Return:
  value of the attribute

Return Type:
  Any

Up

## MultiValueDictResolver

Class used to resolve from Django multi value dictionaries.

### Derived from

DictResolver

### Class Attributes

None

### Class Methods

None

### Methods

getVariableList | Public method to get the attributes of a variable as a list.
resolve | Public method to get an attribute from a variable.

### Static Methods

None

#### MultiValueDictResolver.getVariableList

getVariableList(var)

Public method to get the attributes of a variable as a list.

var (Any)
  variable to be converted

Yield:
  tuple containing the batch start index and a list containing the variable attributes

Yield Type:
  tuple of (int, list)

#### MultiValueDictResolver.resolve

resolve(var, attribute)

Public method to get an attribute from a variable.

var (MultiValueDict)
  variable to extract an attribute or value from
attribute (str)
  name of the attribute to extract

Return:
  value of the attribute

Return Type:
  Any

Up

## NdArrayResolver

Class used to resolve from numpy ndarray including some meta data.

### Derived from

BaseResolver

### Class Attributes

None

### Class Methods

None

### Methods

__isNumeric | Private method to check, if an array is of a numeric type.
getVariableList | Public method to get the attributes of a variable as a list.
resolve | Public method to get an attribute from a variable.

### Static Methods

None

#### NdArrayResolver.__isNumeric

__isNumeric(arr)

Private method to check, if an array is of a numeric type.

arr (ndarray)
  array to check

Return:
  flag indicating a numeric array

Return Type:
  bool

#### NdArrayResolver.getVariableList

getVariableList(var)

Public method to get the attributes of a variable as a list.

var (Any)
  variable to be converted

Yield:
  tuple containing the batch start index and a list containing the variable attributes

Yield Type:
  tuple of (int, list)

#### NdArrayResolver.resolve

resolve(var, attribute)

Public method to get an attribute from a variable.

var (ndarray)
  variable to extract an attribute or value from
attribute (str)
  id of the value to extract

Return:
  value of the attribute

Return Type:
  Any

Up

## QtResolver

Class used to resolve the Qt implementations.

### Derived from

BaseResolver

### Class Attributes

None

### Class Methods

None

### Methods

getVariableList | Public method to get the attributes of a variable as a list.
resolve | Public method to get an attribute from a variable.

### Static Methods

None

#### QtResolver.getVariableList

getVariableList(var)

Public method to get the attributes of a variable as a list.

var (Any)
  variable to be converted

Yield:
  tuple containing the batch start index and a list containing the variable attributes

Yield Type:
  tuple of (int, list)

#### QtResolver.resolve

resolve(var, attribute)

Public method to get an attribute from a variable.

var (Qt objects)
  variable to extract an attribute or value from
attribute (str)
  name of the attribute to extract

Return:
  value of the attribute

Return Type:
  Any

Up

## SetResolver

Class used to resolve from a set or frozenset.

### Derived from

BaseResolver

### Class Attributes

None

### Class Methods

None

### Methods

getVariableList | Public method to get the attributes of a variable as a list.
resolve | Public method to get an attribute from a variable.

### Static Methods

None

#### SetResolver.getVariableList

getVariableList(var)

Public method to get the attributes of a variable as a list.

var (Any)
  variable to be converted

Yield:
  tuple containing the batch start index and a list containing the variable attributes

Yield Type:
  tuple of (int, list)

#### SetResolver.resolve

resolve(var, attribute)

Public method to get an attribute from a variable.

var (tuple or list)
  variable to extract an attribute or value from
attribute (str)
  id of the value to extract

Return:
  value of the attribute

Return Type:
  Any

Up

## _initTypeMap

_initTypeMap()

Protected function to initialize the type map.

Up

## getResolver

getResolver(obj)

Public method to get the resolver based on the type info of an object.

obj (Any)
  object to get resolver for

Return:
  resolver

Return Type:
  BaseResolver

Up

## updateTypeMap

updateTypeMap()

Public function to update the type map based on module imports.

Up